@@ -1,13 +1,17 @@
 __author__ = "Johannes Köster"
-__copyright__ = "Copyright 2021, Johannes Köster"
+__copyright__ = "Copyright 2022, Johannes Köster"
 __email__ = "johannes.koester@protonmail.com"
 __license__ = "MIT"
 
+import concurrent.futures
+import contextlib
 from functools import update_wrapper
 import itertools
+import math
 import platform
 import hashlib
 import inspect
+import threading
 import uuid
 import os
 import asyncio
@@ -16,12 +20,13 @@ import collections
 from pathlib import Path
 
 from snakemake._version import get_versions
+from snakemake.common.tbdstring import TBDString
 
 __version__ = get_versions()["version"]
 del get_versions
 
 
-MIN_PY_VERSION = (3, 5)
+MIN_PY_VERSION = (3, 7)
 DYNAMIC_FILL = "__snakemake_dynamic__"
 SNAKEMAKE_SEARCHPATH = str(Path(__file__).parent.parent.parent)
 UUID_NAMESPACE = uuid.uuid5(uuid.NAMESPACE_URL, "https://snakemake.readthedocs.io")
@@ -32,37 +37,41 @@ NOTHING_TO_BE_DONE_MSG = (
 ON_WINDOWS = platform.system() == "Windows"
 
 
-if sys.version_info < (3, 7):
-
-    def async_run(coroutine):
-        loop = asyncio.get_event_loop()
-        return loop.run_until_complete(coroutine)
-
-else:
-
-    def async_run(coroutine):
-        """Attaches to running event loop or creates a new one to execute a
-        coroutine.
-
-        .. seealso::
-
-             https://github.com/snakemake/snakemake/issues/1105
-             https://stackoverflow.com/a/65696398
-
-        """
-        try:
-            _ = asyncio.get_running_loop()
-        except RuntimeError:
-            asyncio.run(coroutine)
-        else:
-            asyncio.create_task(coroutine)
+def mb_to_mib(mb):
+    return int(math.ceil(mb * 0.95367431640625))
 
 
-# A string that prints as TBD
-class TBDString(str):
-    # the second arg is necessary to avoid problems when pickling
-    def __new__(cls, _=None):
-        return str.__new__(cls, "<TBD>")
+def parse_key_value_arg(arg, errmsg):
+    try:
+        key, val = arg.split("=", 1)
+    except ValueError:
+        raise ValueError(errmsg + f" (Unparseable value: {repr(arg)})")
+    return key, val
+
+
+def dict_to_key_value_args(some_dict: dict, quote_str: bool = True):
+    items = []
+    for key, value in some_dict.items():
+        encoded = (
+            "'{}'".format(value) if quote_str and isinstance(value, str) else value
+        )
+        items.append("{}={}".format(key, encoded))
+    return items
+
+
+def async_run(coroutine):
+    """Attaches to running event loop or creates a new one to execute a
+    coroutine.
+    .. seealso::
+         https://github.com/snakemake/snakemake/issues/1105
+         https://stackoverflow.com/a/65696398
+    """
+    try:
+        _ = asyncio.get_running_loop()
+    except RuntimeError:
+        asyncio.run(coroutine)
+    else:
+        asyncio.create_task(coroutine)
 
 
 APPDIRS = None
@@ -257,3 +266,32 @@ class Gather:
     """A namespace for gather to allow items to be accessed via dot notation."""
 
     pass
+
+
+def get_function_params(func):
+    return inspect.signature(func).parameters
+
+
+def get_input_function_aux_params(func, candidate_params):
+    func_params = get_function_params(func)
+
+    return {k: v for k, v in candidate_params.items() if k in func_params}
+
+
+_pool = concurrent.futures.ThreadPoolExecutor()
+
+
+@contextlib.asynccontextmanager
+async def async_lock(_lock: threading.Lock):
+    """Use a threaded lock form threading.Lock in an async context
+
+    Necessary because asycio.Lock is not threadsafe, so only one thread can safely use
+    it at a time.
+    Source: https://stackoverflow.com/a/63425191
+    """
+    loop = asyncio.get_event_loop()
+    await loop.run_in_executor(_pool, _lock.acquire)
+    try:
+        yield  # the lock is held
+    finally:
+        _lock.release()
