@@ -1,3 +1,4 @@
+from collections import UserDict
 from snakemake.io import not_iterable
 
 
@@ -12,7 +13,7 @@ def format_cli_arg(flag, value, quote=True, skip=False):
 
 
 def format_cli_pos_arg(value, quote=True):
-    if isinstance(value, dict):
+    if isinstance(value, (dict, UserDict)):
         return join_cli_args(repr(f"{key}={val}") for key, val in value.items())
     elif not_iterable(value):
         return repr(value)
