@@ -73,6 +73,7 @@ class ModuleInfo:
         self,
         rules=None,
         name_modifier=None,
+        exclude_rules=None,
         ruleinfo=None,
         skip_global_report_caption=False,
     ):
@@ -84,6 +85,7 @@ class ModuleInfo:
             skip_configfile=self.config is not None,
             skip_validation=self.skip_validation,
             skip_global_report_caption=skip_global_report_caption,
+            rule_exclude_list=exclude_rules,
             rule_whitelist=self.get_rule_whitelist(rules),
             rulename_modifier=get_name_modifier_func(rules, name_modifier),
             ruleinfo_overwrite=ruleinfo,
@@ -140,6 +142,7 @@ class WorkflowModifier:
         skip_global_report_caption=False,
         rulename_modifier=None,
         rule_whitelist=None,
+        rule_exclude_list=None,
         ruleinfo_overwrite=None,
         allow_rule_overwrite=False,
         replace_prefix=None,
@@ -156,6 +159,7 @@ class WorkflowModifier:
             self.skip_validation = parent_modifier.skip_validation
             self.skip_global_report_caption = parent_modifier.skip_global_report_caption
             self.rule_whitelist = parent_modifier.rule_whitelist
+            self.rule_exclude_list = parent_modifier.rule_exclude_list
             self.ruleinfo_overwrite = parent_modifier.ruleinfo_overwrite
             self.allow_rule_overwrite = parent_modifier.allow_rule_overwrite
             self.path_modifier = parent_modifier.path_modifier
@@ -178,6 +182,7 @@ class WorkflowModifier:
         self.skip_validation = skip_validation
         self.skip_global_report_caption = skip_global_report_caption
         self.rule_whitelist = rule_whitelist
+        self.rule_exclude_list = rule_exclude_list
         self.ruleinfo_overwrite = ruleinfo_overwrite
         self.allow_rule_overwrite = allow_rule_overwrite
         self.path_modifier = PathModifier(replace_prefix, prefix, workflow)
@@ -185,7 +190,9 @@ class WorkflowModifier:
         self.namespace = namespace
 
     def skip_rule(self, rulename):
-        return self.rule_whitelist is not None and rulename not in self.rule_whitelist
+        return (
+            self.rule_whitelist is not None and rulename not in self.rule_whitelist
+        ) or (self.rule_exclude_list is not None and rulename in self.rule_exclude_list)
 
     def modify_rulename(self, rulename):
         if self.rulename_modifier is not None:
