@@ -34,7 +34,7 @@ class RemoteProvider(gfal.RemoteProvider):
 
 class RemoteObject(gfal.RemoteObject):
     def _globus(self, *args):
-        cmd = ["globus-url-copy"] + list(args)
+        cmd = ["globus-url-copy"] + self._parallelstreams() + list(args)
         try:
             logger.debug(" ".join(cmd))
             return sp.run(
@@ -56,9 +56,7 @@ class RemoteObject(gfal.RemoteObject):
             source = self.remote_file()
             target = "file://" + os.path.abspath(self.local_file())
 
-            self._globus(
-                "-parallel", "4", "-create-dest", "-recurse", "-dp", source, target
-            )
+            self._globus("-create-dest", "-recurse", "-dp", source, target)
 
             os_sync()
             return self.local_file()
@@ -72,6 +70,14 @@ class RemoteObject(gfal.RemoteObject):
             # first delete file, such that globus does not fail
             self._gfal("rm", target)
 
-        self._globus(
-            "-parallel", "4", "-create-dest", "-recurse", "-dp", source, target
-        )
+            self._globus("-create-dest", "-recurse", "-dp", source, target)
+
+    def _parallelstreams(self):
+        n_streams = 4
+        if "streams" in self.kwargs:
+            n_streams = int(self.kwargs["streams"])
+
+        elif "streams" in self.provider.kwargs:
+            n_streams = int(self.provider.kwargs["streams"])
+
+        return [] if n_streams <= 1 else ["-parallel", str(n_streams)]
