@@ -169,7 +169,11 @@ class shell:
 
         cmd = " ".join((cls._process_prefix, cmd, cls._process_suffix)).strip()
 
-        if env_modules:
+        # If the executor is the submit executor or the jobstep executor for the SLURM
+        # backend, we do not want the environment modules to be activated:
+        # if the rule requires a Python module, snakemake's environment might be
+        # incompatible with the module's environment.
+        if env_modules and "slurm" not in (item.filename for item in inspect.stack()):
             cmd = env_modules.shellcmd(cmd)
             logger.info("Activating environment modules: {}".format(env_modules))
 
