@@ -54,6 +54,15 @@ def generate(dag, path, deploy=["conda", "singularity"], configfiles=None):
         )
 
     for rulename, jobs in groupby(dag.jobs, key=lambda job: job.rule.name):
+        jobs = list(jobs)
+        if jobs[0].rule.norun:
+            logger.info(
+                "Skipping rule {} because it does not execute anything.".format(
+                    rulename
+                )
+            )
+            continue
+
         testpath = path / "test_{}.py".format(rulename)
 
         if testpath.exists():
@@ -79,12 +88,11 @@ def generate(dag, path, deploy=["conda", "singularity"], configfiles=None):
                         if parent.is_absolute():
                             root = str(f.parents[len(f.parents) - 1])
                             parent = str(parent)[len(root) :]
-                            print(parent)
                         target = path / rulename / content_type / parent
-                        os.makedirs(target, exist_ok=True)
                         if f.is_dir():
-                            shutil.copytree(f, target)
+                            shutil.copytree(f, target / f.name)
                         else:
+                            os.makedirs(target, exist_ok=True)
                             shutil.copy(f, target)
                     if not files:
                         os.makedirs(path / rulename / content_type, exist_ok=True)
