@@ -612,7 +612,7 @@ class Paramspace:
     By default, a directory structure with on folder level per parameter is created
     (e.g. column1~{column1}/column2~{column2}/***).
 
-    The exact behavior can be tweaked with three parameters:
+    The exact behavior can be tweaked with four parameters:
 
       - ``filename_params`` takes a list of column names of the passed dataframe.
         These names are used to build the filename (separated by '_') in the order
@@ -638,14 +638,29 @@ class Paramspace:
 
         | ``Paramspace(df, filename_params="*", filename_sep="-")`` ->
         | column1~{value1}-column2~{value2}-column3~{value3}-column4~{value4}
+
+      - ``single_wildcard`` takes a string which is used to replace the
+        default behavior of using a wildcard for each column in the dataframe
+        with a single wildcard that is used to encode all column values.
+        The given string is the name of that wildcard. The value of the wildcard
+        for individual instances of the paramspace is still controlled by above
+        other arguments. The single_wildcard mechanism can be handy if you want
+        to define a rule that shall be used for multiple paramspaces with different
+        columns.
     """
 
     def __init__(
-        self, dataframe, filename_params=None, param_sep="~", filename_sep="_"
+        self,
+        dataframe,
+        filename_params=None,
+        param_sep="~",
+        filename_sep="_",
+        single_wildcard=None,
     ):
         self.dataframe = dataframe
         self.param_sep = param_sep
         self.filename_sep = filename_sep
+        self.single_wildcard = single_wildcard
         if filename_params is None or not filename_params:
             # create a pattern of the form {}/{}/{} with one entry for each
             # column in the dataframe
@@ -683,9 +698,14 @@ class Paramspace:
         """Wildcard pattern over all columns of the underlying dataframe of the form
         column1~{column1}/column2~{column2}/*** or of the provided custom pattern.
         """
-        return self.pattern.format(
-            *map(self.param_sep.join(("{0}", "{{{0}}}")).format, self.ordered_columns)
-        )
+        if self.single_wildcard:
+            return f"{{{self.single_wildcard}}}"
+        else:
+            return self.pattern.format(
+                *map(
+                    self.param_sep.join(("{0}", "{{{0}}}")).format, self.ordered_columns
+                )
+            )
 
     @property
     def instance_patterns(self):
@@ -706,6 +726,7 @@ class Paramspace:
     def instance(self, wildcards):
         """Obtain instance (dataframe row) with the given wildcard values."""
         import pandas as pd
+        from snakemake.io import regex
 
         def convert_value_dtype(name, value):
             if self.dataframe.dtypes[name] == bool and value == "False":
@@ -715,11 +736,35 @@ class Paramspace:
             else:
                 return pd.Series([value]).astype(self.dataframe.dtypes[name])[0]
 
-        return {
-            name: convert_value_dtype(name, value)
-            for name, value in wildcards.items()
-            if name in self.ordered_columns
-        }
+        if self.single_wildcard:
+            wildcard_value = wildcards.get(self.single_wildcard)
+            if wildcard_value is None:
+                raise WorkflowError(
+                    f"Error processing paramspace: wildcard {self.single_wildcard} is not used in rule."
+                )
+
+            pattern = self.pattern.format(
+                *(
+                    f"{name}{self.param_sep}{{{name}}}"
+                    for name in self.dataframe.columns
+                )
+            )
+            rexp = re.compile(regex(pattern))
+            match = rexp.match(wildcard_value)
+            if not match:
+                raise WorkflowError(
+                    f"Error processing paramspace: wildcard {self.single_wildcard}={wildcards.get(self.single_wildcard)} does not match pattern {pattern}."
+                )
+            return {
+                name: convert_value_dtype(name, value)
+                for name, value in match.groupdict().items()
+            }
+        else:
+            return {
+                name: convert_value_dtype(name, value)
+                for name, value in wildcards.items()
+                if name in self.ordered_columns
+            }
 
     def __getattr__(self, name):
         import pandas as pd
