@@ -1,5 +1,5 @@
 __author__ = "Johannes Köster"
-__copyright__ = "Copyright 2021, Johannes Köster"
+__copyright__ = "Copyright 2022, Johannes Köster"
 __email__ = "johannes.koester@uni-due.de"
 __license__ = "MIT"
 
@@ -12,17 +12,20 @@ from urllib.request import urlopen
 
 from snakemake.exceptions import WorkflowError
 from snakemake.script import script
-from snakemake.sourcecache import SourceCache, infer_source_file
+from snakemake.sourcecache import LocalGitFile, SourceCache, infer_source_file
 
 
 PREFIX = "https://github.com/snakemake/snakemake-wrappers/raw/"
 
+EXTENSIONS = [".py", ".R", ".Rmd", ".jl"]
 
-def is_script(path):
+
+def is_script(source_file):
+    filename = source_file.get_filename()
     return (
-        path.endswith("wrapper.py")
-        or path.endswith("wrapper.R")
-        or path.endswith("wrapper.jl")
+        filename.endswith("wrapper.py")
+        or filename.endswith("wrapper.R")
+        or filename.endswith("wrapper.jl")
     )
 
 
@@ -34,7 +37,7 @@ def get_path(path, prefix=None):
             parts = path.split("/")
             path = "/" + "/".join(parts[1:]) + "@" + parts[0]
         path = prefix + path
-    return path
+    return infer_source_file(path)
 
 
 def is_url(path):
@@ -45,24 +48,13 @@ def is_url(path):
     )
 
 
-def is_local(path):
-    return path.startswith("file:")
+def find_extension(source_file, sourcecache: SourceCache):
+    for ext in EXTENSIONS:
+        if source_file.get_filename().endswith("wrapper{}".format(ext)):
+            return source_file
 
-
-def is_git_path(path):
-    return path.startswith("git+file:")
-
-
-def find_extension(
-    path, sourcecache: SourceCache, extensions=[".py", ".R", ".Rmd", ".jl"]
-):
-    for ext in extensions:
-        if path.endswith("wrapper{}".format(ext)):
-            return path
-
-    path = infer_source_file(path)
-    for ext in extensions:
-        script = path.join("wrapper{}".format(ext))
+    for ext in EXTENSIONS:
+        script = source_file.join("wrapper{}".format(ext))
 
         if sourcecache.exists(script):
             return script
@@ -77,11 +69,8 @@ def get_conda_env(path, prefix=None):
     path = get_path(path, prefix=prefix)
     if is_script(path):
         # URLs and posixpaths share the same separator. Hence use posixpath here.
-        path = posixpath.dirname(path)
-    if is_git_path(path):
-        path, version = path.split("@")
-        return os.path.join(path, "environment.yaml") + "@" + version
-    return path + "/environment.yaml"
+        path = path.get_basedir()
+    return path.join("environment.yaml")
 
 
 def wrapper(
@@ -112,11 +101,17 @@ def wrapper(
     Load a wrapper from https://github.com/snakemake/snakemake-wrappers under
     the given path + wrapper.(py|R|Rmd) and execute it.
     """
-    path = get_script(
+    assert path is not None
+    script_source = get_script(
         path, SourceCache(runtime_cache_path=runtime_sourcecache_path), prefix=prefix
     )
+    if script_source is None:
+        raise WorkflowError(
+            f"Unable to locate wrapper script for wrapper {path}. "
+            "This can be a network issue or a mistake in the wrapper URL."
+        )
     script(
-        path,
+        script_source.get_path_or_uri(),
         "",
         input,
         output,
