@@ -21,7 +21,7 @@ import tarfile
 from snakemake import snakemake
 from snakemake.shell import shell
 from snakemake.common import ON_WINDOWS
-from snakemake.resources import DefaultResources, GroupResources
+from snakemake.resources import DefaultResources, GroupResources, ResourceScopes
 
 
 def dpath(path):
@@ -130,6 +130,7 @@ def run(
     container_image=os.environ.get("CONTAINER_IMAGE", "snakemake/snakemake:latest"),
     shellcmd=None,
     sigint_after=None,
+    overwrite_resource_scopes=None,
     **params,
 ):
     """
@@ -223,6 +224,11 @@ def run(
             targets=targets,
             conda_frontend=conda_frontend,
             container_image=container_image,
+            overwrite_resource_scopes=(
+                ResourceScopes(overwrite_resource_scopes)
+                if overwrite_resource_scopes is not None
+                else overwrite_resource_scopes
+            ),
             **params,
         )
 
