@@ -9,7 +9,9 @@ from snakemake import shell
 
 skip_on_windows = pytest.mark.skipif(ON_WINDOWS, reason="Unix stuff")
 only_on_windows = pytest.mark.skipif(not ON_WINDOWS, reason="Windows stuff")
-needs_strace = pytest.mark.xfail(os.system("strace -o /dev/null true") != 0, reason="Missing strace")
+needs_strace = pytest.mark.xfail(
+    os.system("strace -o /dev/null true") != 0, reason="Missing strace"
+)
 
 
 @pytest.fixture(autouse=True)
