@@ -16,8 +16,8 @@ def test_tibanna():
     run(
         workdir,
         use_conda=True,
-        configfiles=[os.path.join(workdir, "config.json")],
         default_remote_prefix="snakemake-tibanna-test/1",
+        tibanna=True,
         tibanna_sfn="tibanna_unicorn_johannes",
-        tibanna_config="spot_instance=true",
+        tibanna_config=["spot_instance=true"],
     )
